@@ -3,7 +3,7 @@ import warnings
 from difflib import SequenceMatcher as SM
 from nltk.util import ngrams
 
-def fuzzy_match(needle, hay, flags=None, needle_length_window=0.2):
+def fuzzy_match(needle, hay, flags=re.DOTALL, needle_length_window=0.2):
     """Searches on the most similar string. 
     Code adapted from: 
     https://stackoverflow.com/questions/17740833/checking-fuzzy-approximate-substring-existing-in-a-longer-string-in-python/31433394#31433394
